package MemcachedSOAP;

import java.net.MalformedURLException;
import java.util.HashMap;
import java.util.Iterator;
import javax.xml.soap.SOAPException;

/**
 * A sample test class for the Java MemcachedSOAPClient.
 * 
 * <p>
 * This class is used to implement a MemcachedSOAPClient and try to call some basic operations
 * on the distant webservice. Basicaly, it just creates a fake session and tries to recover it.
 *
 * <p>
 * This is Open Source software released under the <a href="http://www.gnu.org/licenses/gpl.html">GNU/GPL</a> license.<br />
 * It is provided "as is" without warranty of any kind.<br />
 * Copyright 2007: Nicolas Grevet & Younes Mohmoh, France.<br />
 *
 * <p>
 * Version history:<br />
 * 2007-06-01: first release<br />
 * 2007-06-04: various improvements and fixes.<br />
 */

public class MemcachedSOAPTest
{
	public static void main (String[] args)
	{
		MemcachedSOAPClient clientSOAP = new MemcachedSOAPClient("urn", "MemcachedSOAPClass", "http://192.168.1.5:8080/cgi-bin/MemcachedSOAP.cgi");
		//clientSOAP.setProxy("172.16.3.3", "3128");
		if (clientSOAP.serverStatusOK())
		{
			System.out.println("OK: SOAP Server is up and responding");
			HashMap<String, Object> informations = new HashMap<String, Object>();
			informations.put("uid", "ric GERMAN");
			informations.put("password", 109230918);
			System.out.println("Sending this new session...");
			
			Iterator keys = informations.keySet().iterator();
			while (keys.hasNext())
			{
				Object key = keys.next();
				System.out.println("# "+key+" => "+informations.get(key));
			}
			
			String sessionNum = null;
			try
			{
				sessionNum = clientSOAP.setSession(informations);
			}
			catch (MalformedURLException e)
			{
				System.out.println("ERROR: Malformed webservice uri : "+clientSOAP.getURI());
				System.exit(1);
			}
			catch (SOAPException e)
			{
				System.out.println("ERROR: Unable to create new session");
				System.exit(2);
			}
			
			if (sessionNum != null)
			{
				System.out.println("OK: sessionNum = "+sessionNum);
				System.out.println("\nSearching the session '"+sessionNum+"'...");
				
				HashMap<String, Object> session = new HashMap<String, Object>();
				try
				{
					session = clientSOAP.getSession(sessionNum);
				}
				catch (MalformedURLException e)
				{
					System.out.println("ERROR: Malformed webservice uri : "+clientSOAP.getURI());
					System.exit(3);
				}
				catch (SOAPException e)
				{
					System.out.println("ERROR: Unable to get session "+sessionNum);
					System.exit(4);
				}
				
				// Affichage de la HashMap rcupre (pour tester)
				keys = informations.keySet().iterator();
				boolean firstLoop = true;
				while (keys.hasNext())
				{
					if (firstLoop)
					{
						System.out.println("OK: Session '"+sessionNum+"' found :");
						firstLoop = false;
					}
					Object key = keys.next();
					System.out.println("# "+key+" => "+session.get(key));
				}
				
				if (firstLoop)
				{
					System.out.println("ERROR: Empty session returned !");
				}
			}
			else
			{
				System.out.println("ERROR: Session creation failed !");
			}
		}
		else
		{
			System.out.println("ERROR: SOAP server seems down !");
		}
	}
}
